probnum.statespace
==================

Probabilistic State Space Models.

This package implements components of continuous-discrete and discrete-discrete
state space models, which are the basis for Bayesian filtering and smoothing,
but also for probabilistic ODE solvers.

.. automodapi:: probnum.statespace
    :no-heading:
    :no-main-docstr:
